# KSTAR
Kinase-Substrate Translation to Activity Relationships 

Publication: https://www.nature.com/articles/s41467-022-32017-5

Documentation: https://naeglelab.github.io/KSTAR/index.html

## Feedback?
* Submit a [Feature Request](https://github.com/NaegleLab/KSTAR/issues/new?assignees=&labels=&template=feature_request.md&title=)
* Submit a [Bug Report](https://github.com/NaegleLab/KSTAR/issues/new?assignees=&labels=&template=bug_report.md&title=)
